==============================
CanDIG Server
==============================

.. image:: https://img.shields.io/travis/CanDIG/candig-server/master.svg
   :alt: Current build status on Travis-CI, click for more
   :target: https://travis-ci.org/CanDIG/candig-server

.. image:: https://img.shields.io/codecov/c/github/CanDIG/candig-server/master.svg
   :alt: Current code coverage of master branch, click for details
   :target: https://codecov.io/gh/CanDIG/candig-server

.. image:: https://img.shields.io/readthedocs/candig-server/v1.1.0   
   :alt: Read the Docs (version)
   :target: https://candig-server.readthedocs.io

This is the CanDIG server implementation, a core component of the Canadian health and genomic data sharing platform. It has been built on the `ga4gh-server <https://github.com/ga4gh/ga4gh-server>`_ with extended functionality on metadata support, federated queries, improved search capabilities, etc.

To learn more about the CanDIG project or to contact us, please visit https://www.distributedgenomics.ca.